@@ -57,12 +57,15 @@ str_trim <- function(string) {
 
 ## parses both numbers and functions calling numbers to their numeric value
 str2numeric <- function(string) {
-
-  out <- tryCatch({vapply(string, FUN=function(x){eval(str2lang(x))},
-                          FUN.VALUE=numeric(1), USE.NAMES=FALSE)},
-                  error=function(e){
-                    stop("One or more of the supplied beta coefficients ",
-                         "in 'formula' are not numbers.")})
+  out <- tryCatch({
+    vapply(string,
+           FUN=function(x){eval.parent(str2lang(x), n=6)},
+           FUN.VALUE=numeric(1),
+           USE.NAMES=FALSE)},
+    error=function(e){
+      stop("One or more of the supplied beta coefficients ",
+           "in 'formula' are not numbers.")}
+  )
   return(out)
 }
 
@@ -153,7 +156,7 @@ data_for_formula <- function(data, args) {
   }
 
   # add all variables to model matrix
-  form_dat <- paste0("~ ", paste0(colnames(data), collapse=" + "))
+  form_dat <- paste0("~ `", paste0(colnames(data), collapse="` + `"), "`")
 
   # identify interactions
   form_int <- args$parents[grepl(":", args$parents, fixed=TRUE)]
@@ -270,14 +273,31 @@ is_same_object <- function(fun1, fun2) {
 }
 
 ## check whether a string is a number or a function called on a number
+## or in a special case, eval() called on a variable
 is_valid_number <- function(string) {
-  return(grepl("^(\\d+(\\.\\d+)?|[a-zA-Z]+\\(\\d+(\\.\\d+)?\\))$", string))
+  out <-
+    grepl("^(-?\\d+(\\.\\d+)?)$", string) ||
+    grepl("^([a-zA-Z0-9_\\.]+\\(-?\\d+(\\.\\d+)?\\))$", string) ||
+    grepl("^(eval\\([a-zA-Z0-9_\\.]*\\))$", string)
+  return(out)
 }
 
 ## check whether a string represents an enhanced formula as implemented
 ## in this package
 is_enhanced_formula <- function(string) {
-  out <- grepl("\\*\\s*(-?\\d+|[a-zA-Z]+\\s*\\(-?\\d+\\))", string) ||
+
+  # remove white space
+  string <- gsub(" ", "", string, fixed=TRUE)
+
+  # checks in this order:
+  # 1. contains *NUMBER
+  # 2. contains *FUNCTION(NUMBER)
+  # 3. contains eval(VARIABLE)
+  # 4. contains NUMBER*
+  out <-
+    grepl("\\*-?\\d+(\\.\\d+)?", string) ||
+    grepl("\\*[a-zA-Z0-9_\\.]+\\(-?\\d+(\\.\\d+)?\\)", string) ||
+    grepl("eval\\([a-zA-Z0-9_\\.]*\\)", string) ||
     grepl("\\d+\\)?\\s*\\*", string)
   return(out)
 }
