@@ -4,8 +4,13 @@
 node_negative_binomial <- function(data, parents, formula=NULL, betas,
                                    intercept, theta) {
 
+  if (!data.table::is.data.table(data)) {
+    data.table::setDT(data)
+  }
+
   if (!is.null(formula)) {
-    data <- stats::model.frame(formula=formula, data=data)
+    data <- stats::model.matrix(object=formula, data=data)
+    data <- as.data.frame(data[, -1])
   } else {
     data <- as.data.frame(data[, parents, with=FALSE])
   }
@@ -17,4 +22,3 @@ node_negative_binomial <- function(data, parents, formula=NULL, betas,
 
   return(out)
 }
-
